import os
import sys
from dataclasses import dataclass


@dataclass
class PythonInfo:
    version: str
    executable_path: str
    script_path: str


def whoruv() -> PythonInfo:
    return PythonInfo(
        version=sys.version,
        executable_path=sys.executable,
        script_path=os.path.abspath(__file__),
    )


def format_python_info(info: PythonInfo) -> str:
    return f"""Python Version: {info.version}
Executable Path: {info.executable_path}
Script Path: {info.script_path}
"""



import argparse

from . import __version__
from ._core import format_python_info, whoruv


def main() -> None:
    parser = argparse.ArgumentParser(
        description="Display Python version, executable path, and script path"
    )
    parser.add_argument(
        "-V", "--version", action="version", version=f"%(prog)s v{__version__}"
    )
    parser.parse_args()

    print(format_python_info(whoruv()))


if __name__ == "__main__":
    main()
